@@ -3,7 +3,6 @@
 from sqlalchemy import Boolean
 from sqlalchemy import CheckConstraint
 from sqlalchemy import Column
-from sqlalchemy import event
 from sqlalchemy import exc
 from sqlalchemy import ForeignKey
 from sqlalchemy import Index
@@ -24,20 +23,14 @@ from alembic.testing import assert_raises_message
 from alembic.testing import combinations
 from alembic.testing import config
 from alembic.testing import eq_
+from alembic.testing import expect_warnings
 from alembic.testing import is_not_
 from alembic.testing import mock
-from alembic.testing.fixtures import AlterColRoundTripFixture
 from alembic.testing.fixtures import op_fixture
 from alembic.testing.fixtures import TestBase
 from alembic.util import sqla_compat
 
 
-@event.listens_for(Table, "after_parent_attach")
-def _add_cols(table, metadata):
-    if table.name == "tbl_with_auto_appended_column":
-        table.append_column(Column("bat", Integer))
-
-
 class OpTest(TestBase):
     def test_rename_table(self):
         context = op_fixture()
@@ -417,31 +410,59 @@ class OpTest(TestBase):
             existing_server_default=esd(),
         )
 
-    def test_alter_column_schema_type_unnamed(self):
+    @combinations((True,), (False,), (None,), argnames="existing_nullable")
+    def test_alter_column_schema_type_unnamed(self, existing_nullable):
         context = op_fixture("mssql", native_boolean=False)
-        op.alter_column("t", "c", type_=Boolean(create_constraint=True))
-        context.assert_(
-            "ALTER TABLE t ALTER COLUMN c BIT",
-            "ALTER TABLE t ADD CHECK (c IN (0, 1))",
-        )
+        if existing_nullable is None:
+            with expect_warnings(
+                "MS-SQL ALTER COLUMN operations that specify type_= should"
+            ):
+                op.alter_column(
+                    "t",
+                    "c",
+                    type_=Boolean(create_constraint=True),
+                )
+            context.assert_(
+                "ALTER TABLE t ALTER COLUMN c BIT",
+                "ALTER TABLE t ADD CHECK (c IN (0, 1))",
+            )
+        else:
+            op.alter_column(
+                "t",
+                "c",
+                type_=Boolean(create_constraint=True),
+                existing_nullable=existing_nullable,
+            )
+            context.assert_(
+                f"ALTER TABLE t ALTER COLUMN c BIT "
+                f"{'NULL' if existing_nullable else 'NOT NULL'}",
+                "ALTER TABLE t ADD CHECK (c IN (0, 1))",
+            )
 
     def test_alter_column_schema_schema_type_unnamed(self):
         context = op_fixture("mssql", native_boolean=False)
         op.alter_column(
-            "t", "c", type_=Boolean(create_constraint=True), schema="foo"
+            "t",
+            "c",
+            type_=Boolean(create_constraint=True),
+            existing_nullable=False,
+            schema="foo",
         )
         context.assert_(
-            "ALTER TABLE foo.t ALTER COLUMN c BIT",
+            "ALTER TABLE foo.t ALTER COLUMN c BIT NOT NULL",
             "ALTER TABLE foo.t ADD CHECK (c IN (0, 1))",
         )
 
     def test_alter_column_schema_type_named(self):
         context = op_fixture("mssql", native_boolean=False)
         op.alter_column(
-            "t", "c", type_=Boolean(name="xyz", create_constraint=True)
+            "t",
+            "c",
+            type_=Boolean(name="xyz", create_constraint=True),
+            existing_nullable=False,
         )
         context.assert_(
-            "ALTER TABLE t ALTER COLUMN c BIT",
+            "ALTER TABLE t ALTER COLUMN c BIT NOT NULL",
             "ALTER TABLE t ADD CONSTRAINT xyz CHECK (c IN (0, 1))",
         )
 
@@ -451,10 +472,11 @@ class OpTest(TestBase):
             "t",
             "c",
             type_=Boolean(name="xyz", create_constraint=True),
+            existing_nullable=False,
             schema="foo",
         )
         context.assert_(
-            "ALTER TABLE foo.t ALTER COLUMN c BIT",
+            "ALTER TABLE foo.t ALTER COLUMN c BIT NOT NULL",
             "ALTER TABLE foo.t ADD CONSTRAINT xyz CHECK (c IN (0, 1))",
         )
 
@@ -490,10 +512,11 @@ class OpTest(TestBase):
             "c",
             type_=String(10),
             existing_type=Boolean(name="xyz", create_constraint=True),
+            existing_nullable=False,
         )
         context.assert_(
             "ALTER TABLE t DROP CONSTRAINT xyz",
-            "ALTER TABLE t ALTER COLUMN c VARCHAR(10)",
+            "ALTER TABLE t ALTER COLUMN c VARCHAR(10) NOT NULL",
         )
 
     def test_alter_column_schema_schema_type_existing_type(self):
@@ -503,11 +526,12 @@ class OpTest(TestBase):
             "c",
             type_=String(10),
             existing_type=Boolean(name="xyz", create_constraint=True),
+            existing_nullable=False,
             schema="foo",
         )
         context.assert_(
             "ALTER TABLE foo.t DROP CONSTRAINT xyz",
-            "ALTER TABLE foo.t ALTER COLUMN c VARCHAR(10)",
+            "ALTER TABLE foo.t ALTER COLUMN c VARCHAR(10) NOT NULL",
         )
 
     def test_alter_column_schema_type_existing_type_no_const(self):
@@ -858,6 +882,27 @@ class OpTest(TestBase):
         ck = [c for c in t1.constraints if isinstance(c, CheckConstraint)]
         eq_(ck[0].name, "ck_1")
 
+    def test_create_table_with_check_constraint_with_expr(self):
+        context = op_fixture()
+        foo_id = Column("foo_id", Integer)
+        t1 = op.create_table(
+            "some_table",
+            Column("id", Integer, primary_key=True),
+            foo_id,
+            CheckConstraint(foo_id > 5, name="ck_1"),
+        )
+        context.assert_(
+            "CREATE TABLE some_table ("
+            "id INTEGER NOT NULL, "
+            "foo_id INTEGER, "
+            "PRIMARY KEY (id), "
+            "CONSTRAINT ck_1 CHECK (foo_id > 5))"
+        )
+
+        ck = [c for c in t1.constraints if isinstance(c, CheckConstraint)]
+        eq_(ck[0].name, "ck_1")
+        eq_(len(ck), 1)
+
     def test_create_table_unique_constraint(self):
         context = op_fixture()
         t1 = op.create_table(
@@ -1160,9 +1205,19 @@ class ObjectFromToTest(TestBase):
 
     def test_drop_table(self):
         schema_obj = schemaobj.SchemaObjects()
-        table = schema_obj.table("x", Column("q", Integer))
+        table = schema_obj.table(
+            "x",
+            Column("q", Integer),
+            info={"custom": "value"},
+            prefixes=["FOREIGN"],
+            postgresql_partition_by="x",
+            comment="some comment",
+        )
         op = ops.DropTableOp.from_table(table)
         is_not_(op.to_table(), table)
+        eq_(op.to_table().comment, table.comment)
+        eq_(op.to_table().info, table.info)
+        eq_(op.to_table()._prefixes, table._prefixes)
 
     def test_drop_table_add_kw(self):
         schema_obj = schemaobj.SchemaObjects()
@@ -1179,9 +1234,19 @@ class ObjectFromToTest(TestBase):
 
     def test_create_table(self):
         schema_obj = schemaobj.SchemaObjects()
-        table = schema_obj.table("x", Column("q", Integer))
+        table = schema_obj.table(
+            "x",
+            Column("q", Integer),
+            postgresql_partition_by="x",
+            prefixes=["FOREIGN"],
+            info={"custom": "value"},
+            comment="some comment",
+        )
         op = ops.CreateTableOp.from_table(table)
         is_not_(op.to_table(), table)
+        eq_(op.to_table().comment, table.comment)
+        eq_(op.to_table().info, table.info)
+        eq_(op.to_table()._prefixes, table._prefixes)
 
     def test_create_table_add_kw(self):
         schema_obj = schemaobj.SchemaObjects()
@@ -1235,28 +1300,3 @@ class ObjectFromToTest(TestBase):
         assert_raises_message(
             ValueError, "constraint cannot be produced", op.to_constraint
         )
-
-
-class BackendAlterColumnTest(AlterColRoundTripFixture, TestBase):
-    __backend__ = True
-
-    def test_rename_column(self):
-        self._run_alter_col({}, {"name": "newname"})
-
-    def test_modify_type_int_str(self):
-        self._run_alter_col({"type": Integer()}, {"type": String(50)})
-
-    def test_add_server_default_int(self):
-        self._run_alter_col({"type": Integer}, {"server_default": text("5")})
-
-    def test_modify_server_default_int(self):
-        self._run_alter_col(
-            {"type": Integer, "server_default": text("2")},
-            {"server_default": text("5")},
-        )
-
-    def test_modify_nullable_to_non(self):
-        self._run_alter_col({}, {"nullable": False})
-
-    def test_modify_non_nullable_to_nullable(self):
-        self._run_alter_col({"nullable": False}, {"nullable": True})
